# Chnages made with each version

## v1.0.0
First complete release with assembly, annotation and search for specific genes

## v1.0.3
- Making the databases directory user defined
    - update the version # in baczy.VERSION and in pyproject.toml

